pub struct ConformEngine { /* private fields */ }Expand description
Conforming engine for proxy-to-original workflows.
Implementations
Sourceimpl ConformEngine
impl ConformEngine
Sourcepub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
pub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
Create a new conform engine with the specified link database.
Errors
Returns an error if the database cannot be opened.
Sourcepub async fn conform_from_edl(
&self,
edl_path: impl AsRef<Path>,
output: impl AsRef<Path>,
) -> Result<ConformResult>
pub async fn conform_from_edl( &self, edl_path: impl AsRef<Path>, output: impl AsRef<Path>, ) -> Result<ConformResult>
Sourcepub fn relink(&self, proxy_path: impl AsRef<Path>) -> Result<&Path>
pub fn relink(&self, proxy_path: impl AsRef<Path>) -> Result<&Path>
Relink a single proxy file to its original.
Errors
Returns an error if no link exists for the proxy.
Sourcepub const fn link_manager(&self) -> &ProxyLinkManager
pub const fn link_manager(&self) -> &ProxyLinkManager
Get the link manager.