pub struct LinkDatabase { /* private fields */ }Expand description
Proxy link database.
Implementations
Sourceimpl LinkDatabase
impl LinkDatabase
Sourcepub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
pub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
Create or open a link database at the specified path.
Errors
Returns an error if the database cannot be created or opened.
Sourcepub fn add_link(&mut self, record: ProxyLinkRecord) -> Result<()>
pub fn add_link(&mut self, record: ProxyLinkRecord) -> Result<()>
Add a proxy link to the database.
Sourcepub fn get_link(&self, proxy_path: &Path) -> Option<&ProxyLinkRecord>
pub fn get_link(&self, proxy_path: &Path) -> Option<&ProxyLinkRecord>
Get a link by proxy path.
Sourcepub fn get_link_by_original(
&self,
original_path: &Path,
) -> Option<&ProxyLinkRecord>
pub fn get_link_by_original( &self, original_path: &Path, ) -> Option<&ProxyLinkRecord>
Get a link by original path.
Sourcepub fn remove_link(
&mut self,
proxy_path: &Path,
) -> Result<Option<ProxyLinkRecord>>
pub fn remove_link( &mut self, proxy_path: &Path, ) -> Result<Option<ProxyLinkRecord>>
Remove a link by proxy path.
Sourcepub fn update_verification(
&mut self,
proxy_path: &Path,
timestamp: i64,
) -> Result<()>
pub fn update_verification( &mut self, proxy_path: &Path, timestamp: i64, ) -> Result<()>
Update a link’s verification timestamp.
Sourcepub fn all_links(&self) -> Vec<&ProxyLinkRecord>
pub fn all_links(&self) -> Vec<&ProxyLinkRecord>
Get all links in the database.