pub struct ProxyLinkManager { /* private fields */ }Expand description
Proxy link manager.
Implementations
Sourceimpl ProxyLinkManager
impl ProxyLinkManager
Sourcepub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
pub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
Create a new proxy link manager with the specified database.
Errors
Returns an error if the database cannot be opened.
Sourcepub async fn link_proxy(
&mut self,
proxy_path: impl AsRef<Path>,
original_path: impl AsRef<Path>,
) -> Result<()>
pub async fn link_proxy( &mut self, proxy_path: impl AsRef<Path>, original_path: impl AsRef<Path>, ) -> Result<()>
Sourcepub async fn link_proxy_with_metadata(
&mut self,
proxy_path: impl AsRef<Path>,
original_path: impl AsRef<Path>,
scale_factor: f32,
codec: impl Into<String>,
duration: f64,
timecode: Option<String>,
metadata: HashMap<String, String>,
) -> Result<()>
pub async fn link_proxy_with_metadata( &mut self, proxy_path: impl AsRef<Path>, original_path: impl AsRef<Path>, scale_factor: f32, codec: impl Into<String>, duration: f64, timecode: Option<String>, metadata: HashMap<String, String>, ) -> Result<()>
Link a proxy with full metadata.
Sourcepub fn get_proxy(&self, original_path: impl AsRef<Path>) -> Result<&Path>
pub fn get_proxy(&self, original_path: impl AsRef<Path>) -> Result<&Path>
Get the proxy path for an original file.
Errors
Returns an error if no link exists for the original.