pub struct ProxyLink {
pub proxy_path: String,
pub original_path: String,
pub checksum: u64,
pub created_ms: u64,
}Expand description
An association between a proxy file and its high-resolution original.
Fields
proxy_path: StringPath to the proxy file.
original_path: StringPath to the original (high-resolution) file.
checksum: u64FNV-1a checksum of the proxy content at link creation time.
created_ms: u64Unix timestamp (milliseconds) when the link was created.
Implementations
Sourceimpl ProxyLink
impl ProxyLink
Sourcepub fn new(
proxy_path: impl Into<String>,
original_path: impl Into<String>,
checksum: u64,
created_ms: u64,
) -> Self
pub fn new( proxy_path: impl Into<String>, original_path: impl Into<String>, checksum: u64, created_ms: u64, ) -> Self
Create a new proxy link.
Sourcepub fn is_valid_checksum(&self, data: &[u8]) -> bool
pub fn is_valid_checksum(&self, data: &[u8]) -> bool
Verify that data matches the stored checksum using FNV-1a hashing.
Returns true when the computed hash equals Self::checksum.