pub struct ProxyLinkRegistry {
pub links: Vec<ProxyLink>,
}Expand description
In-memory registry that maps proxy files to their originals.
Fields
links: Vec<ProxyLink>All registered links.
Implementations
Sourceimpl ProxyLinkRegistry
impl ProxyLinkRegistry
Sourcepub fn register(&mut self, proxy: &str, original: &str, checksum: u64)
pub fn register(&mut self, proxy: &str, original: &str, checksum: u64)
Register a proxy↔original association.
If a link for the same proxy path already exists it is replaced.
Sourcepub fn find_original(&self, proxy: &str) -> Option<&str>
pub fn find_original(&self, proxy: &str) -> Option<&str>
Find the original path for a given proxy path.
Returns None if no link exists for the given proxy.
Sourcepub fn find_proxy(&self, original: &str) -> Option<&str>
pub fn find_proxy(&self, original: &str) -> Option<&str>
Find the proxy path for a given original path.
Returns None if the original is not linked to any proxy.