pub struct ProxyReconnector;Expand description
Reconnects a proxy to its original by scanning a set of search paths.
Implementations
Sourceimpl ProxyReconnector
impl ProxyReconnector
Sourcepub fn reconnect(proxy: &str, search_paths: &[String]) -> ReconnectResult
pub fn reconnect(proxy: &str, search_paths: &[String]) -> ReconnectResult
Attempt to reconnect proxy to its original by matching filename suffix.
For each candidate in search_paths, the reconnector checks whether the
candidate path ends with the same filename (or sub-path) as proxy.
Returns
ReconnectResult::Found– exactly one match.ReconnectResult::Ambiguous– more than one match.ReconnectResult::NotFound– no match.