pub struct AutoReconnector { /* private fields */ }Expand description
Attempts to automatically reconnect proxies to originals in a directory.
Implementations
Sourceimpl AutoReconnector
impl AutoReconnector
Sourcepub fn with_extensions(self, exts: Vec<String>) -> Self
pub fn with_extensions(self, exts: Vec<String>) -> Self
Set the file extensions to search for.
Sourcepub fn search_root(&self) -> &Path
pub fn search_root(&self) -> &Path
Get the search root directory.
Sourcepub fn includes_extension(&self, ext: &str) -> bool
pub fn includes_extension(&self, ext: &str) -> bool
Check if the given extension is included in the search.