pub struct RateLimiter { /* private fields */ }Expand description
Rate limiter for proxy transfers using a token bucket algorithm.
Implementations
Sourceimpl RateLimiter
impl RateLimiter
Sourcepub fn with_burst_size(self, bytes: u64) -> Self
pub fn with_burst_size(self, bytes: u64) -> Self
Set the bucket capacity (burst size).
Sourcepub fn try_consume(&mut self, bytes: u64) -> bool
pub fn try_consume(&mut self, bytes: u64) -> bool
Try to consume tokens for a transfer of the given size.
Returns true if the transfer is allowed.
Sourcepub fn available_tokens(&self) -> u64
pub fn available_tokens(&self) -> u64
Current available tokens.