pub struct ProxyIndex { /* private fields */ }Expand description
An in-memory index of proxy entries keyed by original file path.
Implementations
Sourceimpl ProxyIndex
impl ProxyIndex
Sourcepub fn insert(&mut self, entry: ProxyEntry)
pub fn insert(&mut self, entry: ProxyEntry)
Insert a ProxyEntry. Entries with the same original_path are accumulated.
Sourcepub fn find_by_original(&self, original_path: &str) -> &[ProxyEntry]
pub fn find_by_original(&self, original_path: &str) -> &[ProxyEntry]
Find all proxy entries for a given original path.
Sourcepub fn remove(&mut self, original_path: &str) -> Vec<ProxyEntry>
pub fn remove(&mut self, original_path: &str) -> Vec<ProxyEntry>
Remove all entries for a given original path. Returns the removed entries.
Sourcepub fn original_count(&self) -> usize
pub fn original_count(&self) -> usize
Return the number of unique originals in the index.
Sourcepub fn all_entries(&self) -> impl Iterator<Item = &ProxyEntry>
pub fn all_entries(&self) -> impl Iterator<Item = &ProxyEntry>
Return all entries as a flat iterator.
Sourcepub fn contains(&self, original_path: &str) -> bool
pub fn contains(&self, original_path: &str) -> bool
Return true if any proxy entry exists for the given original path.
Sourcepub fn best_quality(&self, original_path: &str) -> Option<&ProxyEntry>
pub fn best_quality(&self, original_path: &str) -> Option<&ProxyEntry>
Find the entry with the highest bitrate for a given original path.