pub struct FrameTimecode {
pub frame_number: u64,
pub fps_num: u32,
pub fps_den: u32,
}Expand description
A timecode value expressed as total frames at a given frame rate.
Fields
frame_number: u64Total frame count from zero.
fps_num: u32Frame rate numerator.
fps_den: u32Frame rate denominator.
Implementations
Sourceimpl FrameTimecode
impl FrameTimecode
Sourcepub fn from_hmsf(
hours: u64,
minutes: u64,
seconds: u64,
frames: u64,
fps: u64,
) -> Self
pub fn from_hmsf( hours: u64, minutes: u64, seconds: u64, frames: u64, fps: u64, ) -> Self
Create a timecode from hours, minutes, seconds, frames at 24fps.
Sourcepub fn as_seconds(&self) -> f64
pub fn as_seconds(&self) -> f64
Duration in seconds.
Sourcepub fn frame_diff(&self, other: &Self) -> i64
pub fn frame_diff(&self, other: &Self) -> i64
Compute the difference in frames from another timecode.
Returns a positive value if self is later than other.