pub struct TimecodeAligner { /* private fields */ }Expand description
Aligns proxy timecode to original timecode using a known offset.
Implementations
Sourceimpl TimecodeAligner
impl TimecodeAligner
Sourcepub fn new(offset_frames: i64, fps_num: u32, fps_den: u32) -> Self
pub fn new(offset_frames: i64, fps_num: u32, fps_den: u32) -> Self
Create an aligner with a known offset.
Sourcepub fn original_to_proxy(&self, original_frame: u64) -> u64
pub fn original_to_proxy(&self, original_frame: u64) -> u64
Compute the proxy frame number for a given original frame number.
Sourcepub fn proxy_to_original(&self, proxy_frame: u64) -> u64
pub fn proxy_to_original(&self, proxy_frame: u64) -> u64
Compute the original frame number for a given proxy frame number.
Sourcepub fn offset_frames(&self) -> i64
pub fn offset_frames(&self) -> i64
Get the frame offset.
Sourcepub fn offset_seconds(&self) -> f64
pub fn offset_seconds(&self) -> f64
Offset expressed in seconds.