pub struct OfflineWorkflow { /* private fields */ }Expand description
Offline editing workflow manager.
Implementations
Sourceimpl OfflineWorkflow
impl OfflineWorkflow
Sourcepub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
pub async fn new(db_path: impl AsRef<Path>) -> Result<Self>
Create a new offline workflow with the specified database.
Errors
Returns an error if the database cannot be opened.