pub enum Quality {
Low,
Medium,
High,
}Expand description
Proxy quality preset for quick setup.
Variants
Low
Low quality, smallest file size (good for remote editing).
Medium
Medium quality, balanced size and quality (recommended for most workflows).
High
High quality, larger files (for critical color work).
Implementations
Sourceimpl Quality
impl Quality
Sourcepub const fn bitrate_1080p(&self) -> u64
pub const fn bitrate_1080p(&self) -> u64
Get the recommended bitrate for this quality level at 1080p.
Sourcepub const fn bitrate_4k(&self) -> u64
pub const fn bitrate_4k(&self) -> u64
Get the recommended bitrate for this quality level at 4K.