pub struct SyncPoint {
pub proxy_tc: FrameTimecode,
pub original_tc: FrameTimecode,
pub verified: bool,
}Expand description
A sync point linking a proxy frame to an original frame.
Fields
proxy_tc: FrameTimecodeTimecode in the proxy media.
original_tc: FrameTimecodeCorresponding timecode in the original media.
verified: boolWhether this sync point was verified by checksum comparison.
Implementations
Sourceimpl SyncPoint
impl SyncPoint
Sourcepub fn new(proxy_tc: FrameTimecode, original_tc: FrameTimecode) -> Self
pub fn new(proxy_tc: FrameTimecode, original_tc: FrameTimecode) -> Self
Create a new sync point.
Sourcepub fn frame_offset(&self) -> i64
pub fn frame_offset(&self) -> i64
Frame offset between proxy and original (in proxy frames).