Module transcode_queue

Module transcode_queue 

Proxy transcode queue management.

Provides a priority-based queue for scheduling and tracking proxy transcode jobs, along with batch request support and queue statistics.

Structs

ProxyBatchRequest
A batch proxy request: transcode many sources with the same spec.
ProxyRequest
A proxy transcode request submitted to the queue.
ProxySpec
Specification for a proxy transcode output.
ProxyTranscodeJob
A proxy transcode job with its current status and timing information.
ProxyTranscodeQueue
Priority-based proxy transcode queue.
QueueStats
Aggregated statistics for a ProxyTranscodeQueue.

Enums

JobStatus
Status of a proxy transcode job.