Proxy transcode queue management.
Provides a priority-based queue for scheduling and tracking proxy transcode jobs, along with batch request support and queue statistics.
Structs
- Proxy
Batch Request - A batch proxy request: transcode many sources with the same spec.
- Proxy
Request - A proxy transcode request submitted to the queue.
- Proxy
Spec - Specification for a proxy transcode output.
- Proxy
Transcode Job - A proxy transcode job with its current status and timing information.
- Proxy
Transcode Queue - Priority-based proxy transcode queue.
- Queue
Stats - Aggregated statistics for a
ProxyTranscodeQueue.
Enums
- JobStatus
- Status of a proxy transcode job.